/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.activemq.artemis.core.protocol.openwire;

import org.apache.activemq.artemis.core.server.routing.RoutingContext;
import org.apache.activemq.command.ConnectionInfo;

public class OpenWireRoutingContext extends RoutingContext {

   private final OpenWireConnection openWireConnection;


   public OpenWireConnection getOpenWireConnection() {
      return openWireConnection;
   }


   public OpenWireRoutingContext(OpenWireConnection openWireConnection, ConnectionInfo connectionInfo) {
      super(openWireConnection.getRemotingConnection(), connectionInfo.getClientId(),
              openWireConnection.getValidatedUser() != null ? openWireConnection.getValidatedUser() : connectionInfo.getUserName());
      this.openWireConnection = openWireConnection;
   }
}
